@@ -194,23 +194,23 @@ class TestUnsupportedFrameworkError:
     
     def test_unsupported_framework_error_creation(self):
         """Test creating UnsupportedFrameworkError."""
-        error = UnsupportedFrameworkError("NA")
+        error = UnsupportedFrameworkError("na")
         
-        assert str(error) == "Unsupported framework: NA"
-        assert error.message == "Unsupported framework: NA"
-        assert error.details == "NA"
-        assert error.framework == "NA"
+        assert str(error) == "Unsupported framework: na"
+        assert error.message == "Unsupported framework: na"
+        assert error.details == "na"
+        assert error.framework == "na"
         assert error.available_frameworks is None
     
     def test_unsupported_framework_error_with_available(self):
         """Test creating UnsupportedFrameworkError with available frameworks."""
         available = ["laravel", "symfony", "codeigniter"]
-        error = UnsupportedFrameworkError("NA", available)
+        error = UnsupportedFrameworkError("na", available)
         
-        assert str(error) == "Unsupported framework: NA. Available frameworks: laravel, symfony, codeigniter"
-        assert error.message == "Unsupported framework: NA. Available frameworks: laravel, symfony, codeigniter"
-        assert error.details == "NA"
-        assert error.framework == "NA"
+        assert str(error) == "Unsupported framework: na. Available frameworks: laravel, symfony, codeigniter"
+        assert error.message == "Unsupported framework: na. Available frameworks: laravel, symfony, codeigniter"
+        assert error.details == "na"
+        assert error.framework == "na"
         assert error.available_frameworks == available
     
     def test_unsupported_framework_error_inheritance(self):
